
char TestVar = 42;

int TestFunc()
{
    return 0;
}
